# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetMeCurrencyResult',
]

@pulumi.output_type
class GetMeCurrencyResult(dict):
    def __init__(__self__, *,
                 code: builtins.str,
                 symbol: builtins.str):
        """
        :param builtins.str code: Currency code used by this account (e.g EUR, USD, ...)
        :param builtins.str symbol: Currency symbol used by this account (e.g €, $, ...)
        """
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "symbol", symbol)

    @property
    @pulumi.getter
    def code(self) -> builtins.str:
        """
        Currency code used by this account (e.g EUR, USD, ...)
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter
    def symbol(self) -> builtins.str:
        """
        Currency symbol used by this account (e.g €, $, ...)
        """
        return pulumi.get(self, "symbol")


