# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .get_installation_template import *
from .get_installation_templates import *
from .get_server import *
from .get_servers import *
from .get_vrack_networks import *
from .provider import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_ovh.cloud as __cloud
    cloud = __cloud
    import pulumi_ovh.cloudproject as __cloudproject
    cloudproject = __cloudproject
    import pulumi_ovh.cloudprojectdatabase as __cloudprojectdatabase
    cloudprojectdatabase = __cloudprojectdatabase
    import pulumi_ovh.config as __config
    config = __config
    import pulumi_ovh.dbaas as __dbaas
    dbaas = __dbaas
    import pulumi_ovh.dedicated as __dedicated
    dedicated = __dedicated
    import pulumi_ovh.domain as __domain
    domain = __domain
    import pulumi_ovh.hosting as __hosting
    hosting = __hosting
    import pulumi_ovh.iam as __iam
    iam = __iam
    import pulumi_ovh.ip as __ip
    ip = __ip
    import pulumi_ovh.iploadbalancing as __iploadbalancing
    iploadbalancing = __iploadbalancing
    import pulumi_ovh.me as __me
    me = __me
    import pulumi_ovh.okms as __okms
    okms = __okms
    import pulumi_ovh.order as __order
    order = __order
    import pulumi_ovh.ovhcloud as __ovhcloud
    ovhcloud = __ovhcloud
    import pulumi_ovh.savingsplan as __savingsplan
    savingsplan = __savingsplan
    import pulumi_ovh.vmware as __vmware
    vmware = __vmware
    import pulumi_ovh.vps as __vps
    vps = __vps
    import pulumi_ovh.vrack as __vrack
    vrack = __vrack
else:
    cloud = _utilities.lazy_import('pulumi_ovh.cloud')
    cloudproject = _utilities.lazy_import('pulumi_ovh.cloudproject')
    cloudprojectdatabase = _utilities.lazy_import('pulumi_ovh.cloudprojectdatabase')
    config = _utilities.lazy_import('pulumi_ovh.config')
    dbaas = _utilities.lazy_import('pulumi_ovh.dbaas')
    dedicated = _utilities.lazy_import('pulumi_ovh.dedicated')
    domain = _utilities.lazy_import('pulumi_ovh.domain')
    hosting = _utilities.lazy_import('pulumi_ovh.hosting')
    iam = _utilities.lazy_import('pulumi_ovh.iam')
    ip = _utilities.lazy_import('pulumi_ovh.ip')
    iploadbalancing = _utilities.lazy_import('pulumi_ovh.iploadbalancing')
    me = _utilities.lazy_import('pulumi_ovh.me')
    okms = _utilities.lazy_import('pulumi_ovh.okms')
    order = _utilities.lazy_import('pulumi_ovh.order')
    ovhcloud = _utilities.lazy_import('pulumi_ovh.ovhcloud')
    savingsplan = _utilities.lazy_import('pulumi_ovh.savingsplan')
    vmware = _utilities.lazy_import('pulumi_ovh.vmware')
    vps = _utilities.lazy_import('pulumi_ovh.vps')
    vrack = _utilities.lazy_import('pulumi_ovh.vrack')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "ovh",
  "mod": "CloudProject/alerting",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/alerting:Alerting": "Alerting"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistry",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistry:ContainerRegistry": "ContainerRegistry"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryIPRestrictionsManagement",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryIPRestrictionsManagement:ContainerRegistryIPRestrictionsManagement": "ContainerRegistryIPRestrictionsManagement"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryIPRestrictionsRegistry",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryIPRestrictionsRegistry:ContainerRegistryIPRestrictionsRegistry": "ContainerRegistryIPRestrictionsRegistry"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryOIDC",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryOIDC:ContainerRegistryOIDC": "ContainerRegistryOIDC"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/containerRegistryUser",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/containerRegistryUser:ContainerRegistryUser": "ContainerRegistryUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/database",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/database:Database": "Database"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/failoverIpAttach",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/failoverIpAttach:FailoverIpAttach": "FailoverIpAttach"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/gateway",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/gateway:Gateway": "Gateway"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/gatewayInterface",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/gatewayInterface:GatewayInterface": "GatewayInterface"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/instance",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/instanceSnapshot",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/instanceSnapshot:InstanceSnapshot": "InstanceSnapshot"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kube",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kube:Kube": "Kube"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeIpRestrictions",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeIpRestrictions:KubeIpRestrictions": "KubeIpRestrictions"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeNodePool",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeNodePool:KubeNodePool": "KubeNodePool"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/kubeOidc",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/kubeOidc:KubeOidc": "KubeOidc"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/loadBalancer",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivate",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivate:NetworkPrivate": "NetworkPrivate"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivateSubnet",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet": "NetworkPrivateSubnet"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/networkPrivateSubnetV2",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/networkPrivateSubnetV2:NetworkPrivateSubnetV2": "NetworkPrivateSubnetV2"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/project",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/project:Project": "Project"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/rancher",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/rancher:Rancher": "Rancher"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionLoadBalancerLogSubscription",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionLoadBalancerLogSubscription:RegionLoadBalancerLogSubscription": "RegionLoadBalancerLogSubscription"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionNetwork",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionNetwork:RegionNetwork": "RegionNetwork"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/regionStoragePresign",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/regionStoragePresign:RegionStoragePresign": "RegionStoragePresign"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/s3Credential",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/s3Credential:S3Credential": "S3Credential"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/s3Policy",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/s3Policy:S3Policy": "S3Policy"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/storage",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/storage:Storage": "Storage"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/user",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/user:User": "User"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/volume",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/volumeBackup",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/volumeBackup:VolumeBackup": "VolumeBackup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProject/workflowBackup",
  "fqn": "pulumi_ovh.cloudproject",
  "classes": {
   "ovh:CloudProject/workflowBackup:WorkflowBackup": "WorkflowBackup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/databaseInstance",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/integration",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/integration:Integration": "Integration"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/ipRestriction",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/ipRestriction:IpRestriction": "IpRestriction"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaAcl",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaAcl:KafkaAcl": "KafkaAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaSchemaRegistryAcl",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaSchemaRegistryAcl:KafkaSchemaRegistryAcl": "KafkaSchemaRegistryAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/kafkaTopic",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/kafkaTopic:KafkaTopic": "KafkaTopic"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/logSubscription",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/logSubscription:LogSubscription": "LogSubscription"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/m3DbNamespace",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace": "M3DbNamespace"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/m3DbUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/m3DbUser:M3DbUser": "M3DbUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/mongoDbPrometheus",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/mongoDbPrometheus:MongoDbPrometheus": "MongoDbPrometheus"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/mongoDbUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/mongoDbUser:MongoDbUser": "MongoDbUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/opensearchPattern",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/opensearchPattern:OpensearchPattern": "OpensearchPattern"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/opensearchUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/opensearchUser:OpensearchUser": "OpensearchUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/postgresSqlConnectionPool",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/postgresSqlConnectionPool:PostgresSqlConnectionPool": "PostgresSqlConnectionPool"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/postgresSqlUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/postgresSqlUser:PostgresSqlUser": "PostgresSqlUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/prometheus",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/prometheus:Prometheus": "Prometheus"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/redisUser",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/redisUser:RedisUser": "RedisUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "CloudProjectDatabase/user",
  "fqn": "pulumi_ovh.cloudprojectdatabase",
  "classes": {
   "ovh:CloudProjectDatabase/user:User": "User"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsCluster",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsCluster:LogsCluster": "LogsCluster"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsInput",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsInput:LogsInput": "LogsInput"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputGraylogStream",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputGraylogStream:LogsOutputGraylogStream": "LogsOutputGraylogStream"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputOpenSearchAlias",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputOpenSearchAlias:LogsOutputOpenSearchAlias": "LogsOutputOpenSearchAlias"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsOutputOpenSearchIndex",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsOutputOpenSearchIndex:LogsOutputOpenSearchIndex": "LogsOutputOpenSearchIndex"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsRole",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsRole:LogsRole": "LogsRole"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsRolePermissionStream",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsRolePermissionStream:LogsRolePermissionStream": "LogsRolePermissionStream"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dbaas/logsToken",
  "fqn": "pulumi_ovh.dbaas",
  "classes": {
   "ovh:Dbaas/logsToken:LogsToken": "LogsToken"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/cephAcl",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/cephAcl:CephAcl": "CephAcl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartition",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartition:NasHAPartition": "NasHAPartition"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartitionAccess",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartitionAccess:NasHAPartitionAccess": "NasHAPartitionAccess"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/nasHAPartitionSnapshot",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/nasHAPartitionSnapshot:NasHAPartitionSnapshot": "NasHAPartitionSnapshot"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/server",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/server:Server": "Server"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverNetworking",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverNetworking:ServerNetworking": "ServerNetworking"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverRebootTask",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverRebootTask:ServerRebootTask": "ServerRebootTask"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverReinstallTask",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverReinstallTask:ServerReinstallTask": "ServerReinstallTask"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Dedicated/serverUpdate",
  "fqn": "pulumi_ovh.dedicated",
  "classes": {
   "ovh:Dedicated/serverUpdate:ServerUpdate": "ServerUpdate"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/dSRecords",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/dSRecords:DSRecords": "DSRecords"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/name",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/name:Name": "Name"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/nameServers",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/nameServers:NameServers": "NameServers"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zone",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneDNSSec",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneDNSSec:ZoneDNSSec": "ZoneDNSSec"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneImport",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneImport:ZoneImport": "ZoneImport"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneRecord",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneRecord:ZoneRecord": "ZoneRecord"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Domain/zoneRedirection",
  "fqn": "pulumi_ovh.domain",
  "classes": {
   "ovh:Domain/zoneRedirection:ZoneRedirection": "ZoneRedirection"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabase",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabase:PrivateDatabase": "PrivateDatabase"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseAllowlist",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseAllowlist:PrivateDatabaseAllowlist": "PrivateDatabaseAllowlist"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseDb",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseDb:PrivateDatabaseDb": "PrivateDatabaseDb"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseUser",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseUser:PrivateDatabaseUser": "PrivateDatabaseUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Hosting/privateDatabaseUserGrant",
  "fqn": "pulumi_ovh.hosting",
  "classes": {
   "ovh:Hosting/privateDatabaseUserGrant:PrivateDatabaseUserGrant": "PrivateDatabaseUserGrant"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/permissionsGroup",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/permissionsGroup:PermissionsGroup": "PermissionsGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/policy",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Iam/resourceGroup",
  "fqn": "pulumi_ovh.iam",
  "classes": {
   "ovh:Iam/resourceGroup:ResourceGroup": "ResourceGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/firewall",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/firewall:Firewall": "Firewall"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/firewallRule",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/firewallRule:FirewallRule": "FirewallRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/ipService",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/ipService:IpService": "IpService"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/mitigation",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/mitigation:Mitigation": "Mitigation"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/move",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/move:Move": "Move"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Ip/reverse",
  "fqn": "pulumi_ovh.ip",
  "classes": {
   "ovh:Ip/reverse:Reverse": "Reverse"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFarm:HttpFarm": "HttpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFarmServer:HttpFarmServer": "HttpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpFrontend:HttpFrontend": "HttpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpRoute",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpRoute:HttpRoute": "HttpRoute"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/httpRouteRule",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/httpRouteRule:HttpRouteRule": "HttpRouteRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/loadBalancer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/refresh",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/refresh:Refresh": "Refresh"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/ssl",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/ssl:Ssl": "Ssl"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFarm:TcpFarm": "TcpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFarmServer:TcpFarmServer": "TcpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpFrontend:TcpFrontend": "TcpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpRoute",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpRoute:TcpRoute": "TcpRoute"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/tcpRouteRule",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/tcpRouteRule:TcpRouteRule": "TcpRouteRule"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFarm",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFarm:UdpFarm": "UdpFarm"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFarmServer",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer": "UdpFarmServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/udpFrontend",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/udpFrontend:UdpFrontend": "UdpFrontend"
  }
 },
 {
  "pkg": "ovh",
  "mod": "IpLoadBalancing/vrackNetwork",
  "fqn": "pulumi_ovh.iploadbalancing",
  "classes": {
   "ovh:IpLoadBalancing/vrackNetwork:VrackNetwork": "VrackNetwork"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/aPIOAuth2Client",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/aPIOAuth2Client:APIOAuth2Client": "APIOAuth2Client"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/identityGroup",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/identityGroup:IdentityGroup": "IdentityGroup"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Me/identityUser",
  "fqn": "pulumi_ovh.me",
  "classes": {
   "ovh:Me/identityUser:IdentityUser": "IdentityUser"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/credential",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/okms",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/okms:Okms": "Okms"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/serviceKey",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/serviceKey:ServiceKey": "ServiceKey"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Okms/serviceKeyJWK",
  "fqn": "pulumi_ovh.okms",
  "classes": {
   "ovh:Okms/serviceKeyJWK:ServiceKeyJWK": "ServiceKeyJWK"
  }
 },
 {
  "pkg": "ovh",
  "mod": "SavingsPlan/savingsPlan",
  "fqn": "pulumi_ovh.savingsplan",
  "classes": {
   "ovh:SavingsPlan/savingsPlan:SavingsPlan": "SavingsPlan"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vps/vps",
  "fqn": "pulumi_ovh.vps",
  "classes": {
   "ovh:Vps/vps:Vps": "Vps"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/cloudProject",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/cloudProject:CloudProject": "CloudProject"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/dedicatedServer",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/dedicatedServer:DedicatedServer": "DedicatedServer"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/dedicatedServerInterface",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/dedicatedServerInterface:DedicatedServerInterface": "DedicatedServerInterface"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipAddress",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipAddress:IpAddress": "IpAddress"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipLoadbalancing",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipLoadbalancing:IpLoadbalancing": "IpLoadbalancing"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/ipV6",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/ipV6:IpV6": "IpV6"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/oVHcloudConnect",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/oVHcloudConnect:OVHcloudConnect": "OVHcloudConnect"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrack",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrack:Vrack": "Vrack"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrackDedicatedCloud",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrackDedicatedCloud:VrackDedicatedCloud": "VrackDedicatedCloud"
  }
 },
 {
  "pkg": "ovh",
  "mod": "Vrack/vrackservices",
  "fqn": "pulumi_ovh.vrack",
  "classes": {
   "ovh:Vrack/vrackservices:Vrackservices": "Vrackservices"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "ovh",
  "token": "pulumi:providers:ovh",
  "fqn": "pulumi_ovh",
  "class": "Provider"
 }
]
"""
)
